@@ -27,19 +27,23 @@ BM <- function(N, ...)  UseMethod("BM")
 
 BM.default <- function(N =1000,M=1,x0=0,t0=0,T=1,Dt=NULL,...)
              {
-    if (!is.numeric(x0)) stop("'x0' must be numeric")
-    if (any(!is.numeric(t0) || !is.numeric(T))) stop(" 't0' and 'T' must be numeric")
-    if (any(!is.numeric(N)  || (N - floor(N) > 0) || N <= 1)) stop(" 'N' must be a positive integer ")
-    if (any(!is.numeric(M)  || (M - floor(M) > 0) || M <= 0)) stop(" 'M' must be a positive integer ")
+    if (!is.numeric(x0)) 
+	   stop("'x0' must be numeric")
+    if (any(!is.numeric(t0) || !is.numeric(T))) 
+	   stop(" 't0' and 'T' must be numeric")
+    if (any(!is.numeric(N)  || (N - floor(N) > 0) || N <= 1)) 
+	   stop(" 'N' must be a positive integer ")
+    if (any(!is.numeric(M)  || (M - floor(M) > 0) || M <= 0)) 
+	   stop(" 'M' must be a positive integer ")
     if (any(t0 < 0 || T < 0 || T <= t0) ) 
-        stop(" please use positive times! (0 <= t0 < T) ")
-    if (missing(Dt)) {
-        t <- seq(t0, T, length = N + 1)
+	        stop(" please use positive times! (0 <= t0 < T) ")
+    if (is.null(Dt)) {
+        Dt <- (T - t0)/N
+        t <- seq(t0, T, by=Dt)
     } else {
         t <- c(t0, t0 + cumsum(rep(Dt, N)))
-        T <- t[N + 1]
+		T <- t[N + 1]
     }
-    Dt <- (T - t0)/N
     res <- data.frame(sapply(1:M,function(i) c(0,cumsum(rnorm(N,mean=0,sd=sqrt(Dt))))))
     names(res) <- paste("X",1:M,sep="")
     X <- ts(res, start = t0, deltat = Dt)
