@@ -31,10 +31,12 @@ fptsde1d <- function(object, ...)  UseMethod("fptsde1d")
 fptsde1d.default <- function(object,boundary,...)
                      {
     class(object) <- "snssde1d"
-    if (any(!is.expression(boundary))) stop(" must be expressions of a constant or time-dependent boundary ")
+    if (any(!is.expression(boundary))) 
+	          stop(" must be expressions of a constant or time-dependent boundary ")
     R   <- data.frame(object$X)
     Bn  <- function(t)  eval(boundary)
-    if(object$x0==Bn(object$t0)) warning(paste("x0 = S(t0) ==> crossing realized at time",object$t0))
+    if(object$x0==Bn(object$t0)) 
+	          warning(paste("x0 = S(t0) ==> crossing realized at time",object$t0))
     F   <- lapply(1:as.numeric(object$M),function(i) stats::approxfun(time(object),as.vector(R[,i])) )
       if (as.numeric(object$x0) > Bn(as.numeric(object$t0))){
            v1  <- sapply(1:length(F),function(i) ifelse(length(which(R[,i] <= Bn(time(object))))==0, NA,min(which(R[,i] <= Bn(time(object))))))
@@ -234,11 +236,13 @@ fptsde2d <- function(object, ...)  UseMethod("fptsde2d")
 fptsde2d.default <- function(object,boundary,...)
                      {
     class(object) <- "snssde2d"
-    if (any(!is.expression(boundary))) stop(" must be expression of a constant or time-dependent boundary ")
+    if (any(!is.expression(boundary))) 
+	         stop(" must be expression of a constant or time-dependent boundary ")
     R1   <- data.frame(object$X)
     R2   <- data.frame(object$Y)
     Bn  <- function(t)  eval(boundary) 
-    if(object$x0==Bn(object$t0) | object$y0==Bn(object$t0) ) warning(paste("x0 = S(t0) or y0 =S(t0) ==> crossing realized at time",object$t0))
+    if(object$x0==Bn(object$t0) | object$y0==Bn(object$t0) ) 
+	         warning(paste("x0 = S(t0) or y0 =S(t0) ==> crossing realized at time",object$t0))
     F1   <- lapply(1:as.numeric(object$M),function(i) stats::approxfun(time(object),as.vector(R1[,i])) )
     F2   <- lapply(1:as.numeric(object$M),function(i) stats::approxfun(time(object),as.vector(R2[,i])) )
     if (as.numeric(object$x0) > Bn(as.numeric(object$t0))){
@@ -536,12 +540,14 @@ fptsde3d <- function(object, ...)  UseMethod("fptsde3d")
 fptsde3d.default <- function(object,boundary,...)
                      {
     class(object) <- "snssde3d"
-    if (any(!is.expression(boundary))) stop(" must be expression of a constant or time-dependent boundary ")
+    if (any(!is.expression(boundary))) 
+	         stop(" must be expression of a constant or time-dependent boundary ")
     R1   <- data.frame(object$X)
     R2   <- data.frame(object$Y)
     R3   <- data.frame(object$Z)	
     Bn  <- function(t)  eval(boundary)
-    if(object$x0==Bn(object$t0) | object$y0==Bn(object$t0) | object$z0==Bn(object$t0) ) warning(paste("x0 = S(t0) or y0 =S(t0) or z0 =S(t0) ==> crossing realized at time",object$t0))
+    if(object$x0==Bn(object$t0) | object$y0==Bn(object$t0) | object$z0==Bn(object$t0) ) 
+	         warning(paste("x0 = S(t0) or y0 =S(t0) or z0 =S(t0) ==> crossing realized at time",object$t0))
     F1   <- lapply(1:as.numeric(object$M),function(i) stats::approxfun(time(object),as.vector(R1[,i])) )
     F2   <- lapply(1:as.numeric(object$M),function(i) stats::approxfun(time(object),as.vector(R2[,i])) )
     F3   <- lapply(1:as.numeric(object$M),function(i) stats::approxfun(time(object),as.vector(R3[,i])) )
